pub struct Relative<A, B = A>{
pub epsilon: <A as AbsDiffEq<B>>::Epsilon,
pub max_relative: <A as AbsDiffEq<B>>::Epsilon,
}Expand description
The requisite parameters for testing for approximate equality using a relative based comparison.
This is not normally used directly, rather via the
assert_relative_{eq|ne}! and relative_{eq|ne}! macros.
Example
use std::f64;
use approx::Relative;
Relative::default().eq(&1.0, &1.0);
Relative::default().epsilon(f64::EPSILON).eq(&1.0, &1.0);
Relative::default().max_relative(1.0).eq(&1.0, &1.0);
Relative::default().epsilon(f64::EPSILON).max_relative(1.0).eq(&1.0, &1.0);
Relative::default().max_relative(1.0).epsilon(f64::EPSILON).eq(&1.0, &1.0);Fields
epsilon: <A as AbsDiffEq<B>>::EpsilonThe tolerance to use when testing values that are close together.
max_relative: <A as AbsDiffEq<B>>::EpsilonThe relative tolerance for testing values that are far-apart.
Implementations
Sourceimpl<A, B> Relative<A, B>
impl<A, B> Relative<A, B>