Struct truck_rendimpl::InstanceCreator[][src]

pub struct InstanceCreator { /* fields omitted */ }

Constroctor for instances

Implementations

impl InstanceCreator[src]

pub fn create_polygon_instance<P: Polygon>(
    &self,
    object: &P,
    desc: &PolygonInstanceDescriptor
) -> PolygonInstance
[src]

Creates PolygonInstance from PolygonMesh and StructuredMesh.

pub fn try_create_shape_instance<S: Shape>(
    &self,
    object: &S,
    desc: &ShapeInstanceDescriptor
) -> Option<ShapeInstance>
[src]

Tries to create ShapeInstance from Shell and Solid.

Failure

Failure occurs when the polylined boundary cannot be converted to the polyline in the surface parameter space. This may be due to the following reasons.

  • A boundary curve is not contained within the surface.
  • The surface is not injective, or is too complecated.
  • The surface is not regular: non-degenerate and differentiable.

pub fn create_shape_instance<S: Shape>(
    &self,
    object: &S,
    desc: &ShapeInstanceDescriptor
) -> ShapeInstance
[src]

Creates ShapeInstance from Shell and Solid.

Panics

Panic occurs when the polylined boundary cannot be converted to the polyline in the surface parameter space. This may be due to the following reasons.

  • A boundary curve is not contained within the surface.
  • The surface is not injective, or is too complecated.
  • The surface is not regular: non-degenerate and differentiable.

pub fn create_wire_frame_instance<S: Shape>(
    &self,
    object: &S,
    desc: &WireFrameInstanceDescriptor
) -> WireFrameInstance
[src]

Creates WireFrameInstance from Shell and Solid.

pub fn create_texture(&self, image: &DynamicImage) -> Arc<Texture>[src]

Creates Texture for attaching faces.