Struct truck_rendimpl::ShapeInstance[][src]

pub struct ShapeInstance { /* fields omitted */ }

Instance of shape: Shell and Solid with geometric data.

One can duplicate shapes with different postures and materials that have the same mesh data. To save memory, mesh data on the GPU can be used again.

The duplicated shape by Clone::clone has the same mesh data and descriptor with original, however, its render id is different from the one of original.

Implementations

impl ShapeInstance[src]

pub fn default_vertex_shader() -> ShaderModuleSource<'static>[src]

Returns the default vertex shader module source.

The GLSL original code is src/shaders/polygon.vert.

pub fn default_fragment_shader() -> ShaderModuleSource<'static>[src]

Returns the default fragment shader module source for non-textured polygons.

The GLSL original code is src/shaders/face.frag.

pub fn default_textured_fragment_shader() -> ShaderModuleSource<'static>[src]

Returns the default fragment shader module source for textured polygons.

The GLSL original code is src/shaders/textured-face.frag.

pub fn pipeline_with_shader(
    &self,
    vertex_shader: ShaderModuleSource<'_>,
    fragment_shader: ShaderModuleSource<'_>,
    device_handler: &DeviceHandler,
    layout: &PipelineLayout,
    sample_count: u32
) -> Arc<RenderPipeline>
[src]

Returns the pipeline with developer's custom shader.

pub fn pipeline_with_shader_module(
    &self,
    vertex_module: &ShaderModule,
    fragment_module: &ShaderModule,
    device_handler: &DeviceHandler,
    layout: &PipelineLayout,
    sample_count: u32
) -> Arc<RenderPipeline>
[src]

Returns the pipeline with developer's custom shader module.

impl ShapeInstance[src]

pub fn clone_instance(&self) -> Self[src]

Clone the instance as another drawn element.

pub fn instance_state(&self) -> &InstanceState[src]

Returns a reference to the instance descriptor.

pub fn instance_state_mut(&mut self) -> &mut InstanceState[src]

Returns the mutable reference to the instance descriptor.

pub fn swap_faces(&mut self, other: &mut Self)[src]

swap render faces